NbtCompoundList

Struct NbtCompoundList 

pub struct NbtCompoundList<'a, 'tape> { /* private fields */ }
A wrapper over NbtCompoundListIter that acts more like a Vec.

Implementations

Source

impl<'a, 'tape> NbtCompoundList<'a, 'tape>

pub fn len(&self) -> usize

Returns the number of tags directly in this list.

Note that due to an internal optimization, this function runs at O(n) if the list has at least 2^24 items. Use Self::approx_len if you want to avoid that.

pub fn approx_len(&self) -> u32

A version of Self::len that saturates at 2^24.

pub fn get(&self, index: usize) -> Option<NbtCompound<'a, 'tape>>

Get the element at the given index. This is O(n) where n is index, so if you’ll be calling this more than once you should probably just use the iterator.

pub fn first(&self) -> Option<NbtCompound<'a, 'tape>>

pub fn last(&self) -> Option<NbtCompound<'a, 'tape>>

pub fn is_empty(&self) -> bool